# TODO

* Use `load_cell` when loading individual cells with multiple nodes.

* Packages tabs:
  * freeradius
  * freeradiusclients
  * freeradiuseapconf
  * freeradiusinterfaces
  * lightsquid
  * menu
  * pfblockerng
  * pfblockernglistsv4
  * pfblockerngtopspammers
  * service
  * servicewatchdog
  * squid
  * squidantivirus
  * squidauth
  * squidcache
  * squidguardacl
  * squidguarddefault
  * squidguarddest
  * squidguardgeneral
  * squidguardrewrite
  * squidguardtime
  * squidnac
  * squidremote
  * squidreversegeneral
  * squidreversepeer
  * squidreverseuri
  * squidtraffic
  * squidusers
  * suricata
  * zabbixagentlts




* [gitlab-ci.yml example](https://gitlab.com/saltstack/pop/heist-salt/-/blob/master/.gitlab-ci.yml)
